==> owncloud-10.0.7.tgz: owncloud/settings/l10n/eu.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Pasahitz okerra",
    "No user supplied" : "Ez da erabiltzailerik zehaztu",
    "Authentication error" : "Autentifikazio errorea",
    "Wrong admin recovery password. Please check the password and try again." : "Administratzailearen berreskuratze pasahitza ez egokia. Mesedez egiaztatu pasahitza eta saiatu berriz.",
    "Unable to change password" : "Ezin izan da pasahitza aldatu",
    "Couldn't send reset email. Please contact your administrator." : "Ezin da berrezartzeko eposta bidali. Mesedez jarri harremetan zure administradorearekin.",
    "Federated Cloud Sharing" : "Federatutako Hodei Partekatzea",
    "Group already exists." : "Taldea dagoeneko existitzen da",
    "Unable to add group." : "Ezin izan da taldea gehitu.",
    "Unable to delete group." : "Ezin izan da taldea ezabatu.",
    "log-level out of allowed range" : "erregistro-maila baimendutako tartetik at",
    "Saved" : "Gordeta",
    "test email settings" : "probatu eposta ezarpenak",
    "Email sent" : "Eposta bidalia",
    "You need to set your user email before being able to send test emails." : "Epostaren erabiltzailea zehaztu behar duzu probako eposta bidali aurretik.",
    "Invalid mail address" : "Posta helbide baliogabea",
    "Unable to create user." : "Ezin izan da erabiltzailea sortu.",
    "Your %s account was created" : "Zure %s kontua sortu da",
    "Unable to delete user." : "Ezin izan da erabiltzailea ezabatu.",
    "Forbidden" : "Debekatuta",
    "Invalid user" : "Baliogabeko erabiiltzailea",
    "Unable to change mail address" : "Ezin izan da posta helbidea aldatu",
    "Your full name has been changed." : "Zure izena aldatu egin da.",
    "Unable to change full name" : "Ezin izan da izena aldatu",
    "__language_name__" : "Euskara",
    "Language changed" : "Hizkuntza aldatuta",
    "Invalid request" : "Baliogabeko eskaera",
    "Admins can't remove themself from the admin group" : "Kudeatzaileak ezin du bere burua kendu kudeatzaile taldetik",
    "Unknown user" : "Erabiltzaile ezezaguna",
    "Couldn't remove app." : "Ezin izan da aplikazioa ezabatu..",
    "All" : "Denak",
    "Enabled" : "Gaitua",
    "Not enabled" : "Gaitu gabe",
    "Please wait...." : "Itxoin mesedez...",
    "Error while disabling app" : "Erroea izan da aplikazioa desgaitzerakoan",
    "Disable" : "Ez-gaitu",
    "Enable" : "Gaitu",
    "Error while enabling app" : "Erroea izan da aplikazioa gaitzerakoan",
    "Updating...." : "Eguneratzen...",
    "Error while updating app" : "Errorea aplikazioa eguneratzen zen bitartean",
    "Updated" : "Eguneratuta",
    "Uninstalling ...." : "Desinstalatzen ...",
    "Error while uninstalling app" : "Erroea izan da aplikazioa desinstalatzerakoan",
    "Uninstall" : "Desinstalatu",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ziur zaude gehitu nahi duzula  \"{domain}\" domeinu fidagarri gisa?",
    "Add trusted domain" : "Gehitu domeinu fidagarria",
    "Valid until {date}" : "{date} arte baliogarria",
    "Delete" : "Ezabatu",
    "Sending..." : "Bidaltzen...",
    "Select a profile picture" : "Profilaren irudia aukeratu",
    "Very weak password" : "Pasahitz oso ahula",
    "Weak password" : "Pasahitz ahula",
    "So-so password" : "Halamoduzko pasahitza",
    "Good password" : "Pasahitz ona",
    "Strong password" : "Pasahitz sendoa",
    "Groups" : "Taldeak",
    "Unable to delete {objName}" : "Ezin izan da {objName} ezabatu",
    "A valid group name must be provided" : "Baliozko talde izena eman behar da",
    "deleted {groupName}" : "{groupName} ezbatuta",
    "undo" : "desegin",
    "never" : "inoiz",
    "deleted {userName}" : "{userName} ezabatuta",
    "add group" : "gehitu taldea",
    "enabled" : "gaituta",
    "disabled" : "desgaituta",
    "no group" : "talderik ez",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Pasahitza aldatzeak datuen galera eragingo du, erabiltzaile honetarako datuen berreskuratzea eskuragarri ez dagoelako",
    "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
    "A valid password must be provided" : "Baliozko pasahitza eman behar da",
    "A valid email must be provided" : "Baliozko posta elektronikoa eman behar da",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Kaixo,<br><br>orain %s kontu bat duzula esateko besterik ez.<br><br>Zure erabiltzailea: %s<br>Sar zaitez: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Ongi izan!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Kaixo,\n\norain %s kontu bat duzula esateko besterik ez.\n\nZure erabiltzailea: %s\nSar zaitez: %s\n\n",
    "Forum" : "Foroa",
    "Documentation:" : "Dokumentazioa:",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aplikazioa ezin da instalatu hurrengo menpekotasunak betetzen ez direlako:",
    "Enable only for specific groups" : "Baimendu bakarri talde espezifikoetarako",
    "Uninstall App" : "Desinstalatu aplikazioa",
    "Cron" : "Cron",
    "Cron was not executed yet!" : "Cron-a oraindik ez da exekutatu!",
    "Execute one task with each page loaded" : "Exekutatu zeregin bat orri karga bakoitzean",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php webcron zerbitzu batean erregistratua dago cron.php  15 minuturo http bidez deitzeko.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Erabili sistemaren cron zerbitzua deitzeko cron.php fitxategia 15 minutuan behin.",
    "Common Name" : "Izen arrunta",
    "Valid until" : "Data hau arte baliogarria",
    "Issued By" : "Honek bidalita",
    "Valid until %s" : "%s arte baliogarria",
    "Sharing" : "Partekatzea",
    "Allow apps to use the Share API" : "Baimendu aplikazioak partekatzeko APIa erabiltzeko",
    "Allow users to share via link" : "Baimendu erabiltzaileak esteken bidez partekatzea",
    "Allow public uploads" : "Baimendu igoera publikoak",
    "Enforce password protection" : "Betearazi pasahitzaren babesa",
    "Set default expiration date" : "Ezarri muga data lehenetsia",
    "Allow users to send mail notification for shared files" : "Baimendu erabiltzaileak epostako jakinarazpenak bidaltzen partekatutako fitxategientzat",
    "Expire after " : "Iraungia honen ondoren",
    "days" : "egun",
    "Enforce expiration date" : "Muga data betearazi",
    "Allow resharing" : "Baimendu birpartekatzea",
    "Restrict users to only share with users in their groups" : "Mugatu partekatzeak taldeko erabiltzaileetara",
    "Allow users to send mail notification for shared files to other users" : "Baimendu erabiltzaileak beste erabiltzaileei epostako jakinarazpenak bidaltzen partekatutako fitxategientzat",
    "Exclude groups from sharing" : "Baztertu taldeak partekatzean",
    "These groups will still be able to receive shares, but not to initiate them." : "Talde hauek oraindik jaso ahal izango dute partekatzeak, baina ezingo dute partekatu",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Dena (arazo larriak, erroreak, abisuak, informazioa, arazketa)",
    "Info, warnings, errors and fatal issues" : "Informazioa, abisuak, erroreak eta arazo larriak.",
    "Warnings, errors and fatal issues" : "Abisuak, erroreak eta arazo larriak",
    "Errors and fatal issues" : "Erroreak eta arazo larriak",
    "Fatal issues only" : "Bakarrik arazo larriak",
    "Log" : "Log",
    "None" : "Ezer",
    "Login" : "Saio hasiera",
    "Plain" : "Arrunta",
    "NT LAN Manager" : "NT LAN Manager",
    "This is used for sending out notifications." : "Hau jakinarazpenak bidaltzeko erabiltzen da.",
    "Send mode" : "Bidaltzeko modua",
    "Encryption" : "Enkriptazioa",
    "From address" : "Helbidetik",
    "mail" : "posta",
    "Authentication method" : "Autentifikazio metodoa",
    "Authentication required" : "Autentikazioa beharrezkoa",
    "Server address" : "Zerbitzariaren helbidea",
    "Port" : "Portua",
    "Credentials" : "Kredentzialak",
    "SMTP Username" : "SMTP erabiltzaile-izena",
    "SMTP Password" : "SMTP pasahitza",
    "Store credentials" : "Gorde kredentzialak",
    "Test email settings" : "Probatu eposta ezarpenak",
    "Send email" : "Bidali eposta",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Bakarrik irakurtzeko konfigurazioa gaitu da. Honek web-interfazearen bidez konfigurazio batzuk aldatzea ekiditzen du. Are gehiago, fitxategia eskuz ezarri behar da idazteko moduan eguneraketa bakoitzerako.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Badirudi PHP konfiguratuta dagoela lineako dokumentu blokeak aldatzeko. Honek zenbait oinarrizko aplikazio eskuraezin bihurtuko ditu.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hau ziur aski cache/accelerator batek eragin du, hala nola Zend OPcache edo eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP 'fileinfo' modulua falta da. Modulu hau gaitzea aholkatzen dizugu mime-type ezberdinak hobe detektatzeko.",
    "System locale can not be set to a one which supports UTF-8." : "Eskualdeko ezarpena ezin da UTF-8 onartzen duen batera ezarri.",
    "This means that there might be problems with certain characters in file names." : "Honek esan nahi du fitxategien izenetako karaktere batzuekin arazoak egon daitezkeela.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Biziki gomendatzen dizugu beharrezkoak diren paketea zure sisteman instalatzea honi euskarria eman ahal izateko: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Zure instalazioa ez badago domeinuaren sustraian egina eta erabiltzen badu sistemaren cron-a, arazoak izan daitezke URL sorreran. Arazo horiek saihesteko ezarri  \"overwrite.cli.url\" opzioa zure config.php fitxategian zure instalazioaren webroot bidera (Proposatua: \"%s\")",
    "Get the apps to sync your files" : "Lortu aplikazioak zure fitxategiak sinkronizatzeko",
    "Desktop client" : "Mahaigaineko bezeroa",
    "Android app" : "Android aplikazioa",
    "iOS app" : "iOS aplikazioa",
    "Show First Run Wizard again" : "Erakutsi berriz Lehenengo Aldiko Morroia",
    "Profile picture" : "Profilaren irudia",
    "Upload new" : "Igo berria",
    "Remove image" : "Irudia ezabatu",
    "Cancel" : "Ezeztatu",
    "No display name set" : "Ez da bistaratze izena ezarri",
    "Email" : "E-posta",
    "Your email address" : "Zure e-posta",
    "No email address set" : "Ez da eposta helbidea ezarri",
    "Password" : "Pasahitza",
    "Unable to change your password" : "Ezin izan da zure pasahitza aldatu",
    "Current password" : "Uneko pasahitza",
    "New password" : "Pasahitz berria",
    "Change password" : "Aldatu pasahitza",
    "Language" : "Hizkuntza",
    "Help translate" : "Lagundu itzultzen",
    "Unlimited" : "Mugarik gabe",
    "Name" : "Izena",
    "Username" : "Erabiltzaile izena",
    "Done" : "Egina",
    "Version" : "Bertsioa",
    "Personal" : "Pertsonala",
    "Admin" : "Admin",
    "Error" : "Errorea",
    "Show storage location" : "Erakutsi biltegiaren kokapena",
    "Show last log in" : "Erakutsi azkeneko saio hasiera",
    "Show user backend" : "Bistaratu erabiltzaile motorra",
    "Send email to new user" : "Bidali eposta erabiltzaile berriari",
    "Show email address" : "Bistaratu eposta helbidea",
    "E-Mail" : "E-posta",
    "Create" : "Sortu",
    "Admin Recovery Password" : "Administratzailearen pasahitza berreskuratzea",
    "Enter the recovery password in order to recover the users files during password change" : "Berreskuratze pasahitza idatzi pasahitz aldaketan erabiltzaileen fitxategiak berreskuratzeko",
    "Add Group" : "Gehitu taldea",
    "Group" : "Taldea",
    "Everyone" : "Edonor",
    "Admins" : "Administratzaileak",
    "Default Quota" : "Kuota lehentsia",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Mesedez sartu biltegiratze kouta (adb: \"512 MB\" edo \"12 GB\")",
    "Other" : "Bestelakoa",
    "Full Name" : "Izena",
    "Group Admin for" : "Talde administradorea honentzat",
    "Quota" : "Kuota",
    "Storage Location" : "Biltegiaren kokapena",
    "User Backend" : "Erabiltzaile motorra",
    "Last Login" : "Azken saio hasiera",
    "change full name" : "aldatu izena",
    "set new password" : "ezarri pasahitz berria",
    "change email address" : "aldatu eposta helbidea",
    "Default" : "Lehenetsia"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/settings/l10n/eu.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Pasahitz okerra",
    "No user supplied" : "Ez da erabiltzailerik zehaztu",
    "Authentication error" : "Autentifikazio errorea",
    "Wrong admin recovery password. Please check the password and try again." : "Administratzailearen berreskuratze pasahitza ez egokia. Mesedez egiaztatu pasahitza eta saiatu berriz.",
    "Unable to change password" : "Ezin izan da pasahitza aldatu",
    "Couldn't send reset email. Please contact your administrator." : "Ezin da berrezartzeko eposta bidali. Mesedez jarri harremetan zure administradorearekin.",
    "Federated Cloud Sharing" : "Federatutako Hodei Partekatzea",
    "Group already exists." : "Taldea dagoeneko existitzen da",
    "Unable to add group." : "Ezin izan da taldea gehitu.",
    "Unable to delete group." : "Ezin izan da taldea ezabatu.",
    "log-level out of allowed range" : "erregistro-maila baimendutako tartetik at",
    "Saved" : "Gordeta",
    "test email settings" : "probatu eposta ezarpenak",
    "Email sent" : "Eposta bidalia",
    "You need to set your user email before being able to send test emails." : "Epostaren erabiltzailea zehaztu behar duzu probako eposta bidali aurretik.",
    "Invalid mail address" : "Posta helbide baliogabea",
    "Unable to create user." : "Ezin izan da erabiltzailea sortu.",
    "Your %s account was created" : "Zure %s kontua sortu da",
    "Unable to delete user." : "Ezin izan da erabiltzailea ezabatu.",
    "Forbidden" : "Debekatuta",
    "Invalid user" : "Baliogabeko erabiiltzailea",
    "Unable to change mail address" : "Ezin izan da posta helbidea aldatu",
    "Your full name has been changed." : "Zure izena aldatu egin da.",
    "Unable to change full name" : "Ezin izan da izena aldatu",
    "__language_name__" : "Euskara",
    "Language changed" : "Hizkuntza aldatuta",
    "Invalid request" : "Baliogabeko eskaera",
    "Admins can't remove themself from the admin group" : "Kudeatzaileak ezin du bere burua kendu kudeatzaile taldetik",
    "Unknown user" : "Erabiltzaile ezezaguna",
    "Couldn't remove app." : "Ezin izan da aplikazioa ezabatu..",
    "All" : "Denak",
    "Enabled" : "Gaitua",
    "Not enabled" : "Gaitu gabe",
    "Please wait...." : "Itxoin mesedez...",
    "Error while disabling app" : "Erroea izan da aplikazioa desgaitzerakoan",
    "Disable" : "Ez-gaitu",
    "Enable" : "Gaitu",
    "Error while enabling app" : "Erroea izan da aplikazioa gaitzerakoan",
    "Updating...." : "Eguneratzen...",
    "Error while updating app" : "Errorea aplikazioa eguneratzen zen bitartean",
    "Updated" : "Eguneratuta",
    "Uninstalling ...." : "Desinstalatzen ...",
    "Error while uninstalling app" : "Erroea izan da aplikazioa desinstalatzerakoan",
    "Uninstall" : "Desinstalatu",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ziur zaude gehitu nahi duzula  \"{domain}\" domeinu fidagarri gisa?",
    "Add trusted domain" : "Gehitu domeinu fidagarria",
    "Valid until {date}" : "{date} arte baliogarria",
    "Delete" : "Ezabatu",
    "Sending..." : "Bidaltzen...",
    "Select a profile picture" : "Profilaren irudia aukeratu",
    "Very weak password" : "Pasahitz oso ahula",
    "Weak password" : "Pasahitz ahula",
    "So-so password" : "Halamoduzko pasahitza",
    "Good password" : "Pasahitz ona",
    "Strong password" : "Pasahitz sendoa",
    "Groups" : "Taldeak",
    "Unable to delete {objName}" : "Ezin izan da {objName} ezabatu",
    "A valid group name must be provided" : "Baliozko talde izena eman behar da",
    "deleted {groupName}" : "{groupName} ezbatuta",
    "undo" : "desegin",
    "never" : "inoiz",
    "deleted {userName}" : "{userName} ezabatuta",
    "add group" : "gehitu taldea",
    "enabled" : "gaituta",
    "disabled" : "desgaituta",
    "no group" : "talderik ez",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Pasahitza aldatzeak datuen galera eragingo du, erabiltzaile honetarako datuen berreskuratzea eskuragarri ez dagoelako",
    "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
    "A valid password must be provided" : "Baliozko pasahitza eman behar da",
    "A valid email must be provided" : "Baliozko posta elektronikoa eman behar da",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Kaixo,<br><br>orain %s kontu bat duzula esateko besterik ez.<br><br>Zure erabiltzailea: %s<br>Sar zaitez: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Ongi izan!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Kaixo,\n\norain %s kontu bat duzula esateko besterik ez.\n\nZure erabiltzailea: %s\nSar zaitez: %s\n\n",
    "Forum" : "Foroa",
    "Documentation:" : "Dokumentazioa:",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aplikazioa ezin da instalatu hurrengo menpekotasunak betetzen ez direlako:",
    "Enable only for specific groups" : "Baimendu bakarri talde espezifikoetarako",
    "Uninstall App" : "Desinstalatu aplikazioa",
    "Cron" : "Cron",
    "Cron was not executed yet!" : "Cron-a oraindik ez da exekutatu!",
    "Execute one task with each page loaded" : "Exekutatu zeregin bat orri karga bakoitzean",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php webcron zerbitzu batean erregistratua dago cron.php  15 minuturo http bidez deitzeko.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Erabili sistemaren cron zerbitzua deitzeko cron.php fitxategia 15 minutuan behin.",
    "Common Name" : "Izen arrunta",
    "Valid until" : "Data hau arte baliogarria",
    "Issued By" : "Honek bidalita",
    "Valid until %s" : "%s arte baliogarria",
    "Sharing" : "Partekatzea",
    "Allow apps to use the Share API" : "Baimendu aplikazioak partekatzeko APIa erabiltzeko",
    "Allow users to share via link" : "Baimendu erabiltzaileak esteken bidez partekatzea",
    "Allow public uploads" : "Baimendu igoera publikoak",
    "Enforce password protection" : "Betearazi pasahitzaren babesa",
    "Set default expiration date" : "Ezarri muga data lehenetsia",
    "Allow users to send mail notification for shared files" : "Baimendu erabiltzaileak epostako jakinarazpenak bidaltzen partekatutako fitxategientzat",
    "Expire after " : "Iraungia honen ondoren",
    "days" : "egun",
    "Enforce expiration date" : "Muga data betearazi",
    "Allow resharing" : "Baimendu birpartekatzea",
    "Restrict users to only share with users in their groups" : "Mugatu partekatzeak taldeko erabiltzaileetara",
    "Allow users to send mail notification for shared files to other users" : "Baimendu erabiltzaileak beste erabiltzaileei epostako jakinarazpenak bidaltzen partekatutako fitxategientzat",
    "Exclude groups from sharing" : "Baztertu taldeak partekatzean",
    "These groups will still be able to receive shares, but not to initiate them." : "Talde hauek oraindik jaso ahal izango dute partekatzeak, baina ezingo dute partekatu",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Dena (arazo larriak, erroreak, abisuak, informazioa, arazketa)",
    "Info, warnings, errors and fatal issues" : "Informazioa, abisuak, erroreak eta arazo larriak.",
    "Warnings, errors and fatal issues" : "Abisuak, erroreak eta arazo larriak",
    "Errors and fatal issues" : "Erroreak eta arazo larriak",
    "Fatal issues only" : "Bakarrik arazo larriak",
    "Log" : "Log",
    "None" : "Ezer",
    "Login" : "Saio hasiera",
    "Plain" : "Arrunta",
    "NT LAN Manager" : "NT LAN Manager",
    "This is used for sending out notifications." : "Hau jakinarazpenak bidaltzeko erabiltzen da.",
    "Send mode" : "Bidaltzeko modua",
    "Encryption" : "Enkriptazioa",
    "From address" : "Helbidetik",
    "mail" : "posta",
    "Authentication method" : "Autentifikazio metodoa",
    "Authentication required" : "Autentikazioa beharrezkoa",
    "Server address" : "Zerbitzariaren helbidea",
    "Port" : "Portua",
    "Credentials" : "Kredentzialak",
    "SMTP Username" : "SMTP erabiltzaile-izena",
    "SMTP Password" : "SMTP pasahitza",
    "Store credentials" : "Gorde kredentzialak",
    "Test email settings" : "Probatu eposta ezarpenak",
    "Send email" : "Bidali eposta",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Bakarrik irakurtzeko konfigurazioa gaitu da. Honek web-interfazearen bidez konfigurazio batzuk aldatzea ekiditzen du. Are gehiago, fitxategia eskuz ezarri behar da idazteko moduan eguneraketa bakoitzerako.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Badirudi PHP konfiguratuta dagoela lineako dokumentu blokeak aldatzeko. Honek zenbait oinarrizko aplikazio eskuraezin bihurtuko ditu.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hau ziur aski cache/accelerator batek eragin du, hala nola Zend OPcache edo eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP 'fileinfo' modulua falta da. Modulu hau gaitzea aholkatzen dizugu mime-type ezberdinak hobe detektatzeko.",
    "System locale can not be set to a one which supports UTF-8." : "Eskualdeko ezarpena ezin da UTF-8 onartzen duen batera ezarri.",
    "This means that there might be problems with certain characters in file names." : "Honek esan nahi du fitxategien izenetako karaktere batzuekin arazoak egon daitezkeela.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Biziki gomendatzen dizugu beharrezkoak diren paketea zure sisteman instalatzea honi euskarria eman ahal izateko: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Zure instalazioa ez badago domeinuaren sustraian egina eta erabiltzen badu sistemaren cron-a, arazoak izan daitezke URL sorreran. Arazo horiek saihesteko ezarri  \"overwrite.cli.url\" opzioa zure config.php fitxategian zure instalazioaren webroot bidera (Proposatua: \"%s\")",
    "Get the apps to sync your files" : "Lortu aplikazioak zure fitxategiak sinkronizatzeko",
    "Desktop client" : "Mahaigaineko bezeroa",
    "Android app" : "Android aplikazioa",
    "iOS app" : "iOS aplikazioa",
    "Show First Run Wizard again" : "Erakutsi berriz Lehenengo Aldiko Morroia",
    "Profile picture" : "Profilaren irudia",
    "Upload new" : "Igo berria",
    "Remove image" : "Irudia ezabatu",
    "Cancel" : "Ezeztatu",
    "No display name set" : "Ez da bistaratze izena ezarri",
    "Email" : "E-posta",
    "Your email address" : "Zure e-posta",
    "No email address set" : "Ez da eposta helbidea ezarri",
    "Password" : "Pasahitza",
    "Unable to change your password" : "Ezin izan da zure pasahitza aldatu",
    "Current password" : "Uneko pasahitza",
    "New password" : "Pasahitz berria",
    "Change password" : "Aldatu pasahitza",
    "Language" : "Hizkuntza",
    "Help translate" : "Lagundu itzultzen",
    "Unlimited" : "Mugarik gabe",
    "Name" : "Izena",
    "Username" : "Erabiltzaile izena",
    "Done" : "Egina",
    "Version" : "Bertsioa",
    "Personal" : "Pertsonala",
    "Admin" : "Admin",
    "Error" : "Errorea",
    "Show storage location" : "Erakutsi biltegiaren kokapena",
    "Show last log in" : "Erakutsi azkeneko saio hasiera",
    "Show user backend" : "Bistaratu erabiltzaile motorra",
    "Send email to new user" : "Bidali eposta erabiltzaile berriari",
    "Show email address" : "Bistaratu eposta helbidea",
    "E-Mail" : "E-posta",
    "Create" : "Sortu",
    "Admin Recovery Password" : "Administratzailearen pasahitza berreskuratzea",
    "Enter the recovery password in order to recover the users files during password change" : "Berreskuratze pasahitza idatzi pasahitz aldaketan erabiltzaileen fitxategiak berreskuratzeko",
    "Add Group" : "Gehitu taldea",
    "Group" : "Taldea",
    "Everyone" : "Edonor",
    "Admins" : "Administratzaileak",
    "Default Quota" : "Kuota lehentsia",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Mesedez sartu biltegiratze kouta (adb: \"512 MB\" edo \"12 GB\")",
    "Other" : "Bestelakoa",
    "Full Name" : "Izena",
    "Group Admin for" : "Talde administradorea honentzat",
    "Quota" : "Kuota",
    "Storage Location" : "Biltegiaren kokapena",
    "User Backend" : "Erabiltzaile motorra",
    "Last Login" : "Azken saio hasiera",
    "change full name" : "aldatu izena",
    "set new password" : "ezarri pasahitz berria",
    "change email address" : "aldatu eposta helbidea",
    "Default" : "Lehenetsia",
    "Share" : "Partekatu",
    "Add" : "Gehitu",
    "%s password changed successfully" : "%s pasahitza behar bezala aldatu da",
    "Email has been changed successfully." : "Helbide elektronikoa behar bezala aldatu da"
},
"nplurals=2; plural=(n != 1);");
